# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["EmbeddingCreateParams"]


class EmbeddingCreateParams(TypedDict, total=False):
    input: Required[object]

    model: Required[str]

    dimensions: int

    encoding_format: str

    user: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["Usage", "CompletionTokensDetails", "PromptTokensDetails"]


class CompletionTokensDetails(BaseModel):
    accepted_prediction_tokens: int

    audio_tokens: int

    reasoning_tokens: int

    rejected_prediction_tokens: int


class PromptTokensDetails(BaseModel):
    audio_tokens: int

    cached_tokens: int


class Usage(BaseModel):
    completion_tokens: int

    completion_tokens_details: CompletionTokensDetails

    prompt_tokens: int

    prompt_tokens_details: PromptTokensDetails

    total_tokens: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["FunctionCallParam"]


class FunctionCallParam(TypedDict, total=False):
    arguments: str

    name: str
